==> katapult-trinity_3.5.13.2.orig.tar.xz: katapult-trinity-3.5.13.2/katapult/plugins/catalogs/execcatalog/command.cpp <==
/***************************************************************************
 *   Copyright (C) 2007  Martin Meredith                                   *
 *   mez@ubuntu.com                                                        *
 *                                                                         *
 *   Copyright (C) 2006  Jonathan Riddell                                  *
 *   jriddell@ubuntu.com                                                   *
 *                                                                         *
 *   Copyright (C) 2005 by Joe Ferris                                      *
 *   jferris@optimistictech.com                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

#include <kservice.h> 
#include <kglobal.h>
#include <kiconloader.h>
#include <kapplication.h>

#include <tqclipboard.h>

#include "execcatalog.h"
#include "command.h"


Command::Command(ExecCatalog* catalog, const TQString& text): KatapultItem(), _catalog(catalog), _text(text)
{
}

Command::~Command() {
}

TQPixmap Command::icon(int size) const
{
	return KGlobal::iconLoader()->loadIcon("konsole", KIcon::NoGroup, size);
}

TQString Command::text() const
{
	return _text;
}

void Command::setText(const TQString& text)
{
	_text = text;
}

ExecCatalog* Command::catalog() const
{
	return _catalog;
}


#include "command.moc"

==> katapult-trinity_14.1.5.orig.tar.xz: katapult-trinity-14.1.5/katapult/plugins/catalogs/execcatalog/command.cpp <==
/***************************************************************************
 *   Copyright (C) 2007  Martin Meredith                                   *
 *   mez@ubuntu.com                                                        *
 *                                                                         *
 *   Copyright (C) 2006  Jonathan Riddell                                  *
 *   jriddell@ubuntu.com                                                   *
 *                                                                         *
 *   Copyright (C) 2005 by Joe Ferris                                      *
 *   jferris@optimistictech.com                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

#include <kservice.h> 
#include <tdeglobal.h>
#include <kiconloader.h>
#include <tdeapplication.h>

#include <tqclipboard.h>

#include "execcatalog.h"
#include "command.h"


Command::Command(ExecCatalog* catalog, const TQString& text): KatapultItem(), _catalog(catalog), _text(text)
{
}

Command::~Command() {
}

TQPixmap Command::icon(int size) const
{
	return TDEGlobal::iconLoader()->loadIcon("konsole", TDEIcon::NoGroup, size);
}

TQString Command::text() const
{
	return _text;
}

void Command::setText(const TQString& text)
{
	_text = text;
}

ExecCatalog* Command::catalog() const
{
	return _catalog;
}


#include "command.moc"
